@@ -4,7 +4,7 @@ use warnings;
 
 package Geo::Openstreetmap::Parser;
 {
-  $Geo::Openstreetmap::Parser::VERSION = '0.01';
+  $Geo::Openstreetmap::Parser::VERSION = '0.011';
 }
 
 # ABSTRACT: Openstreetmap XML dump parser
@@ -82,7 +82,7 @@ Geo::Openstreetmap::Parser - Openstreetmap XML dump parser
 
 =head1 VERSION
 
-version 0.01
+version 0.011
 
 =head1 METHODS
 
@@ -92,9 +92,25 @@ Creates a parser object
 
     my $parser = Geo::Openstreetmap::Parser->new( node => \&process_node, ... );
 
+    sub process_node {
+        my ($obj) = @_;
+        ...
+    }
+
+Callbacks are possible for any tag, but useful for osm primitives:
+    node
+    way
+    relation
+
+Callback function receives hash with params:
+    attr    - hash with xml attributes
+    tag     - hash with osm tags
+    nd      - array of node_ids (for ways)
+    member  - array of hashes like { type => 'way', role => 'from', ref => '-1' } (for relations)
+
 =head2 parse
 
-Parses XML input, executing callback functions for every OSM object
+Parses XML input, executing defined callback functions for OSM objects
 
     $parser->parse( *STDIN );
 
